@@ -1,4 +1,10 @@
 package Terminal::Control;
+# ----------------------------------------------------
+# Exit script if operating system Windows is detected.
+# ----------------------------------------------------
+if ($^O eq "MSWin32") {
+    exit 1;
+};
 
 # Load the basic Perl pragmas.
 use 5.030000;
@@ -8,11 +14,6 @@ use warnings;
 # Load the Perl pragma Exporter.
 use Exporter;
 
-#/*
-# * Ref.: https://metacpan.org/release/INGY/Inline-0.25/view/lib/Inline/C/Tutorial.pod
-# *       https://metacpan.org/dist/Inline-C/view/lib/Inline/C/Cookbook.pod
-#*/
-
 # Load the neccessary Perl modules.
 use bytes;
 use Try::Catch;
@@ -22,14 +23,44 @@ use Inline 'C' => <<'END_OF_C_CODE';
 #include <stdio.h>
 #include <termios.h>
 
+/*
+ * Ref.: 
+ *   https://metacpan.org/release/INGY/Inline-0.25/view/lib/Inline/C/Tutorial.pod
+ *   https://metacpan.org/dist/Inline-C/view/lib/Inline/C/Cookbook.pod
+ *   https://metacpan.org/pod/perlguts
+ */
+
+char* TermType() {
+    char *term_type = getenv("TERM");
+    return term_type;
+};
+
+char* TermColor() {
+    char *term_color = getenv("COLORTERM");
+    return term_color;
+};
+
+char* TermName() {
+   static char term[L_ctermid];
+   const char *ptr = ctermid(term);
+   char* term_name = (ptr != NULL) ? ptr : NULL; 
+   return term_name;
+};
+
+char* TermPath() {
+  char* tty_name = ttyname(STDIN_FILENO);
+  char* term_path = (tty_name != NULL) ? tty_name : NULL;
+  return term_path;
+};
+
 /* Ref.: termios(3) - Linux manual page
  *
  * struct termios {
- *       tcflag_t c_iflag;     => input modes
- *       tcflag_t c_oflag;     => output modes
- *       tcflag_t c_cflag;     => control modes
- *       tcflag_t c_lflag;     => local modes
- *       cc_t     c_cc[NCCS];  => special characters
+ *     tcflag_t c_iflag;     => input modes
+ *     tcflag_t c_oflag;     => output modes
+ *     tcflag_t c_cflag;     => control modes
+ *     tcflag_t c_lflag;     => local modes
+ *     cc_t     c_cc[NCCS];  => special characters
  * }
 */
 
@@ -62,12 +93,11 @@ int off_echo() {
     return 1;
 };
 
-/* Define the function io_on(). */
 /*
- * Function: io_on()
- * -----------------
+ * Function: echo_icanon_on()
+ * --------------------------
  */
-int io_on() {
+int echo_icanon_on() {
     /* Read attributes, modify attributes and write attributes back. */
     tcgetattr(fileno(stdin), &term);
     term.c_lflag |= (ECHO | ICANON);
@@ -77,10 +107,10 @@ int io_on() {
 }
 
 /*
- * Function: io_off()
- * ------------------
+ * Function: echo_icanon_off()
+ * ---------------------------
  */
-int io_off() {
+int echo_icanon_off() {
     /* Read attributes, modify attributes and write attributes back. */
     tcgetattr(fileno(stdin), &term);
     term.c_lflag &= ~(ECHO | ICANON);
@@ -90,25 +120,21 @@ int io_off() {
 };
 
 /*
- * Function: winsize()
+ * Function: WinSize()
  * -------------------
  *
  * Get the window size of a terminal window.
  *
  * Ref.: ioctl_tty(2) - Linux manual page
+ *
  * struct winsize {
  *     unsigned short (uint16_t) ws_row;
  *     unsigned short (uint16_t) ws_col;
  *     unsigned short (uint16_t) ws_xpixel;
  *     unsigned short (uint16_t) ws_ypixel;
  * };
- *
- * Ref.: 
- *   https://metacpan.org/release/INGY/Inline-0.25/view/lib/Inline/C/Tutorial.pod
- *   https://metacpan.org/dist/Inline-C/view/lib/Inline/C/Cookbook.pod
- *   https://metacpan.org/pod/perlguts
  */
-void WINSIZE() {
+void WinSize() {
     struct winsize ws;
     ioctl(STDIN_FILENO, TIOCGWINSZ, &ws);
     Inline_Stack_Vars;
@@ -123,7 +149,7 @@ void WINSIZE() {
 END_OF_C_CODE
 
 # Set the package version. 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 # Base class of this module.
 our @ISA = qw(Exporter);
@@ -132,29 +158,39 @@ our @ISA = qw(Exporter);
 our @EXPORT = qw(
     reset_screen
     clear_screen
-    reset_terminal  
-    clear_terminal  
+    reset_terminal
+    clear_terminal
     reset
     clear
     winsize
     chars
     pixels
-    get_cursor_position
-    set_cursor_position
-    echo_on
-    echo_off 
-    cursor_on
-    cursor_off
-    winsize_pixels
+    winsize_ioctl
+    winsize_stty
+    WinSize
     screen_size_pixels
     screen_size_chars
     window_size_chars
     window_size_pixels
+    get_cursor_position
+    set_cursor_position
+    echo_on
+    echo_off
+    cursor_on
+    cursor_off
     ctlseqs_request
     on_echo
     off_echo
-    winsize_ic
-    change
+    TermColor
+    TermName
+    TermPath
+    TermType
+    echo_icanon_on
+    echo_icanon_off
+    cursor_up
+    cursor_down
+    cursor_forward
+    cursor_back
 );
 
 # Set the global variables.
@@ -173,11 +209,6 @@ my $timeout;
 
 # BEGIN block.
 BEGIN {
-    # Try to use Inline C program code.
-    #eval {
-    #    use Inline 'C';
-    #    1;
-    #};
     # Try to load Time::HiRes
     eval {
         require Time::HiRes;
@@ -348,6 +379,7 @@ sub set_cursor_position {
 # Description:                                                                 #
 # Get the response from escape sequence.                                       #
 #------------------------------------------------------------------------------# 
+use IO::Handle;
 sub ctlseqs_request {
     # Assign the subroutine arguments to the local variables.
     my ($Ps, $user_timeout) = @_;
@@ -356,25 +388,28 @@ sub ctlseqs_request {
     # Change the timeout if neccessary.
     $timeout = (defined $user_timeout) ? $user_timeout : $timeout;
     if ($is_alarm eq 1) {
+        # Divide given timeout by microseconds.
         $timeout = int($timeout / 1000000);
     };
     $timeout = ($timeout <= 0) ? 1 : $timeout; 
     # Initialise the local variables.
+    local $/ = \64;
     my ($width, $height) = undef;
     my $buf = '';
     my $chr = '';
+    my $match;
+    my @nums;
     # Change the settings of the terminal window.
     system "stty cbreak -echo -echonl -echoke -echoe -isig </dev/tty >/dev/tty 2>&1";
     # Print the escape sequence to STDOUT.
     print STDOUT "${CSI}${Ps}t";
     # Non blocking reading from STDIN.
-    my $match;
-    my @nums;
     eval {
         # Define the alarm handler.
         local $SIG{ALRM} = sub {die "timeout"};
         # Start the alarm.
         eval "$mod_alarm $timeout";
+        # Read chars from STDIN.
         while (($chr = getc(STDIN)) ne "t") {
             $buf .= $chr;
         };
@@ -384,25 +419,34 @@ sub ctlseqs_request {
     if ($@) {
          # print "timedout\n";
          try {
+             # On error die.
              die;
          } catch {
+             # Clean up settings.  
              system "stty -cbreak echo echonl echoke echoe isig </dev/tty >/dev/tty 2>&1";
-             return (-3, -3);
+             # Return error code -3. 
+             #return (-3, -3);
+             # Set output to error code -3. 
+             ($height, $width) = (-3, -3);
          };
     } else {
         if ($buf eq '') {
-            # Set width and height.
+            # Set output to error code -1. 
             ($width, $height) = (-1, -1);
         } else {
+            # Set regular expression.
             my $re = qr/^.*(\d+\;\d+\;\d+).*$/;
+            # Grep numbers from response.
             if ($buf =~ $re) {
                 $match = $1;
                 @nums = split(";", $match);
             };
             # Get width and height.
             if ($id eq $nums[0]) { 
+                # Set height and width.
                 ($height, $width) = ($nums[1], $nums[2]);
             } else {
+                # Set output to error code -2. 
                 ($height, $width) = (-2, -2);
             };
     };
@@ -426,7 +470,7 @@ sub window_size_pixels {
     # Set the timeout.
     my $timeout = $_[0];
     # Get width and height.
-    my ($width, $height) = ctlseqs_request("14", $timeout);
+    my ($height, $width) = ctlseqs_request("14", $timeout);
     # Return height and width.
     return ($height, $width);
 };
@@ -444,7 +488,7 @@ sub screen_size_pixels {
     # Set the timeout.
     my $timeout = $_[0];
     # Get width and height.
-    my ($width, $height) = ctlseqs_request("15", $timeout);
+    my ($height, $width) = ctlseqs_request("15", $timeout);
     # Return height and width.
     return ($height, $width);
 };
@@ -486,33 +530,7 @@ sub screen_size_chars {
 };
 
 #------------------------------------------------------------------------------# 
-# Subroutine winsizwe_pixels                                                   #
-#                                                                              #
-# Description:                                                                 #
-# Get winsize in pixels.                                                       #
-#------------------------------------------------------------------------------# 
-sub winsize_pixels {
-    # Initialise the local variables.
-    my $seq = '';
-    my $chr = '';
-    # Change the settings of the terminal window.
-    system "stty cbreak -echo </dev/tty >/dev/tty 2>&1";
-    # Print escape sequence.
-    print STDOUT "${CSI}14t";
-    # Read chars von STDIN.
-    while (($chr = getc(STDIN)) ne "t") {
-        $seq .= $chr;
-    };
-    # Restore the settings of the terminal window.
-    system "stty -cbreak echo </dev/tty >/dev/tty 2>&1";
-    # Get rows and cols.
-    my ($x, $y) = $seq =~ m/(\d+)\;(\d+)$/;
-    # Return rows and cols.
-    return ($x, $y)
-};
-
-#------------------------------------------------------------------------------# 
-# Subroutine winsize                                                           #
+# Subroutine winsize_ioctl                                                     #
 #                                                                              #
 # Description:                                                                 #
 # Get winsize using system ioctl call.                                         #
@@ -534,7 +552,7 @@ sub winsize_ioctl {
 };
 
 #------------------------------------------------------------------------------# 
-# Subroutine winsize                                                           #
+# Subroutine winsize_stty                                                      #
 #                                                                              #
 # Description:                                                                 #
 # Get winsize using system stty.                                               #
@@ -585,6 +603,34 @@ sub pixels {
     return ($xpix, $ypix);
 };
 
+sub cursor_up {
+    # Set the control sequence.
+    my $ctl_seq = "1A"; 
+    # Move the cursor up.
+    print "${CSI}${ctl_seq}";
+};
+
+sub cursor_down {
+    # Set the control sequence.
+    my $ctl_seq = "1B"; 
+    # Move the cursor down.
+    print "${CSI}${ctl_seq}";
+};
+
+sub cursor_forward {
+    # Set the control sequence.
+    my $ctl_seq = "1C"; 
+    # Move the cursor forward.
+    print "${CSI}${ctl_seq}";
+};
+
+sub cursor_back {
+    # Set the control sequence.
+    my $ctl_seq = "1D"; 
+    # Move the cursor back.
+    print "${CSI}${ctl_seq}";
+};
+
 1;
 
 __END__
@@ -598,39 +644,62 @@ Terminal::Control - Perl extension with methods for the control of the terminal
 
   use Terminal::Control;
 
+  # Clear or reset the terminal window.
+
   clear_screen();
   reset_screen();
 
+  # Get the terminal window size using /sys/ioctl.ph or stty. 
+
   ($rows, $cols, $xpix, $ypix) = winsize();
   ($rows, $cols) = chars();
   ($xpix, $ypix) = pixels();
 
-  ($row, $col) = get_cursor_position();
-  set_cursor_position($row, $col);
-
-  echo_on();
-  echo_off();
-  
-  cursor_on();
-  cursor_off();   
+  # Get the terminal window size using Xterm control sequences. 
 
   ($rows, $cols) = window_size_chars([$timeout]);  
   ($xpix, $ypix) = windows_size_pixels([$timeout]);
   ($rows, $cols) = screen_size_chars([$timeout]); 
   ($xpix, $ypix) = screen_size_pixels([$timeout]);
 
+  # Get the terminal window size using Inline C code using sys/ioctl.h.
+
+  ($rows, $cols, $xpix, $ypix) = Terminal::Control::WinSize();
+
+  # Get and set the Cursor position on the terminal window.
+
+  ($row, $col) = get_cursor_position();
+  set_cursor_position($row, $col);
+
+  # Show or hide the cursor on the terminal window.
+  
+  cursor_on();
+  cursor_off();   
+
+  # Turn the terminal character echo on or off.  
+
+  echo_on();
+  echo_off();
+
 Variables in square brackets in the method call are optional. They are in the
 related method predefined.
 
 =head1 DESCRIPTION
 
-=head2 Module description
+=head2 Preface
+
+There are two areas of application for the methods presented. They are useful
+in the terminal emulator or terminal for short. However, they also work in the
+system consoles.
+
+=head2 Methods summary
 
 The module contains a collection of methods to control a terminal window. The
-basic methods are used to delete and reset a terminal window and to query the
-current window size.
+basic methods are used to delete or reset a terminal window and to query the
+current window size. Other methods showed or suppressed the input echo. Showing
+or hiding the cursor is achieved by other methods.
 
-=head2 Implemented methods
+=head2 Methods implemented
 
 The following methods have been implemented so far within the module.
 The methods below are sorted according to their logical relationship.
@@ -645,6 +714,24 @@ The methods below are sorted according to their logical relationship.
 
 =over 4 
 
+=item * screen_size_chars($timeout) 
+
+=item * screen_size_pixels($timeout)
+
+=item * window_size_chars($timeout)
+
+=item * windows_size_pixels($timeout)
+
+=back
+
+=over 4 
+
+=item * Terminal::Control::WinSize()
+
+=back
+
+=over 4 
+
 =item * get_cursor_position()
 
 =item * set_cursor_position($rows, $cols)
@@ -663,14 +750,6 @@ The methods below are sorted according to their logical relationship.
 
 =over 4 
 
-=item * echo_on()
-
-=item * echo_off()
-
-=back
-
-=over 4 
-
 =item * cursor_on()
 
 =item * cursor_off()
@@ -679,13 +758,9 @@ The methods below are sorted according to their logical relationship.
 
 =over 4 
 
-=item * screen_size_chars($timeout) 
+=item * echo_on()
 
-=item * screen_size_pixels($timeout)
-
-=item * window_size_chars($timeout)
-
-=item * windows_size_pixels($timeout)
+=item * echo_off()
 
 =back
 
@@ -705,27 +780,47 @@ ANSI escape sequences to STDOUT. The standard terminal window is STDOUT for
 the output of Perl. This command has the same effect like calling the Perl 
 command C<system("reset")>.
 
-B<echo_on>
+B<winsize()> 
 
-Turn the echo on. The method uses for the moment the Shell command C<stty> for 
-turning the echo of (user) input on. 
+Get the window size.  The method is using the Perl-header for the system call
+C<ioctl> and the call or command C<TIOCGWINSZ>. The call returns the winsize in
+rows and cols and xpix and ypix.
 
-B<echo_off>
+B<chars()>
 
-Turn the echo off. The method uses for the moment the Shell command C<stty> for 
-turning the echo of (user) input off. 
+Get the window size in chars. The method extract chars (rows and cols) from the
+former winsize.
 
-Turn the echo off.
+B<pixels()>
 
-B<cursor_on>
+Get the window size in pixels. The method pixels extract pixels (xpix and ypix)
+from the former winsize.
 
-Turn the cursor on. The cursor is enabled by using ANSI escape sequences
-in the method.
+B<window_size_chars([$timeout]);>  
+ 
+Get the window size in chars. The methods gets the window size in chars using
+Xterm control sequences.
 
-B<cursor_off>
+B<windows_size_pixels([$timeout]);>
 
-Turn the cursor off. The cursor is disabled by using ANSI escape sequences
-in the method.
+Get the window size in pixels. The methods gets the window size in pixels using 
+Xterm control sequences.
+
+B<screen_size_chars([$timeout]);>
+
+Get the screen size in chars. The methods gets the screen size in chars using
+Xterm control sequences.
+
+B<screen_size_pixels([$timeout]);>
+
+Get the screen size in pixels. The methods gets the screen size in pixels using 
+Xterm control sequences.
+
+B<Terminal::Control::WinSize()>
+
+Get the window size in chars and pixels. The method is using in The Inline C code 
+the C-header for the system call C<ioctl> and the call or command C<TIOCGWINSZ>. The
+call returns the winsize in rows, cols, xpix and ypix.
 
 B<get_cursor_position()>
 
@@ -737,25 +832,38 @@ B<set_cursor_position($row, $col)>
 Set the cursor position. The method gets the current cursor position in the 
 terminal window.
 
-B<window_size_chars([$timeout]);>  
+B<cursor_on>
 
-B<windows_size_pixels([$timeout]);>
+Turn the cursor on. The cursor is enabled by using ANSI escape sequences
+in the method.
 
-B<screen_size_chars([$timeout]);> 
+B<cursor_off>
 
-B<screen_size_pixels([$timeout]);>
+Turn the cursor off. The cursor is disabled by using ANSI escape sequences
+in the method.
 
-B<winsize()> 
+B<echo_on>
 
-Get the window size. The method gets the dimensions in x-direction and y-direction
-of the terminal. The methods chars and pixels extract chars (rows and cols)
-and pixels (xpix and ypix) from the winsize data. The method is using the C-header
-for the system call C<ioctl> and the call or command C<TIOCGWINSZ>. The call
-returns the winsize in rows and cols and xpix and ypix.
+Turn the echo on. The method uses for the moment the Shell command C<stty> for 
+turning the echo of (user) input on. 
+
+B<echo_off>
+
+Turn the echo off. The method uses for the moment the Shell command C<stty> for 
+turning the echo of (user) input off. 
 
 Variables in square brackets in the method call are optional. They are in the
 related method predefined.
 
+=head1 ERROR CODES
+
+The error codes of methods which are related to getting the window or sreen
+size are as follows:
+
+  -1  ->  Unspecific common error
+  -2  ->  Data from response not valid
+  -3  ->  Execution block timed out
+
 =head1 EXAMPLES
 
   # Clear the terminal window using ANSI escape sequences.
@@ -769,13 +877,26 @@ related method predefined.
   printf ("%s\n%s\n%s\n%s\n", $rows, $cols, $xpix, $ypix);
 
   # Get the chars from the window size and output the result on the screen.
-  ($rows, $cols) = chars();
+  my ($rows, $cols) = chars();
   printf ("%s\n%s\n", $rows, $cols);
 
   # Get the pixels from the window size and output the result on the screen.
-  ($xpix, $ypix) = pixels();
+  my ($xpix, $ypix) = pixels();
   printf ("%s\n%s\n", $xpix, $ypix);
 
+  # Set the timeout for reading from STDIN in microseconds.
+  my $timeout = 1000000;
+  # Get the window and the screen size using Xterm control sequences.
+  # $timeout is optional. If not set 1000000 microseconds (1 second) are used.
+  my ($rows, $cols) = window_size_chars($timeout);
+  my ($xpix, $ypix) = windows_size_pixels($timeout);
+  my ($rows, $cols) = screen_size_chars($timeout);
+  my ($xpix, $ypix) = screen_size_pixels($timeout);
+
+  # Get the window size using Inline C code.
+  my ($rows, $cols, $xpix, $ypix) = Terminal::Control::WinSize();
+  printf ("%s\n%s\n%s\n%s\n", $rows, $cols, $xpix, $ypix);
+
   # Get the cursor position in chars (not in pixels) using ANSI escape sequences.
   my ($row, $col) = get_cursor_position();
   printf ("%s\n%s\n", $row, $col);
@@ -786,26 +907,17 @@ related method predefined.
   # $row and $col are required and must be set by the user.
   set_cursor_position($row, $col);
 
-  # Enable echoing of commands using stty. 
-  echo_on();
-
-  # Disable echoing of commands using stty. 
-  echo_off();
-
   # Enable visibility of the cursor using ANSI escape sequences.
   cursor_on();
 
   # Disable visibility of the cursor using ANSI escape sequences.
   cursor_off();
 
-  # Set the timeout for reading from STDIN in microseconds.
-  my $timeout = 1000000;
-  # Get the window and the screen size using XTERM control sequences.
-  # $timeout is optional. If not set 1000000 microseconds (1 second) are used.
-  ($rows, $cols) = window_size_chars($timeout);
-  ($xpix, $ypix) = windows_size_pixels($timeout);
-  ($rows, $cols) = screen_size_chars($timeout);
-  ($xpix, $ypix) = screen_size_pixels($timeout);
+  # Enable echoing of commands using stty. 
+  echo_on();
+
+  # Disable echoing of commands using stty. 
+  echo_off();
 
 =head1 VARIABLES EXPLANATION
 
@@ -852,27 +964,31 @@ Using C<reset> on the command line and the Perl command C<system("reset")> have
 the same result in time of execution. Detailed comparison is outstanding. This one example
 already shows a significant advantage of the new routine.
 
-=head2 Non-blocking behaviour  
+=head2 Remark on Xterm control sequences  
 
-Reading from STDIN is blocking w.r.t. to the request of escape sequences, if no
-data are available. To overcome the problem of waiting endless for user input a
-timeout is programmed. Unfortunately, the programming implementation also slows
-down the processing when data is available in STDIN. If the standard value is not
-applicable, reduce the timeout step by step. If the timeout is to short the method
-is not able to catch the input from STDIN. A error code -1 is returned.
+The use of Xterm escape sequences is still considered experimental.
+
+Reading from STDIN is blocking with respect to the request of escape sequences,
+if no data are responded. To overcome the problem of waiting endless for an user
+input a timeout is programmed. 
+
+If the standard value is not applicable, reduce the timeout step by step. If the
+timeout is to short the method is not able to catch the input from STDIN. 
 
 =head1 SYSTEM COMPATIBILITY
 
 Three things must be fulfilled in order to use the full functionality of the
 module.
 
-On operating systems that support ANSI escape sequences, individual
-methods will work out of the box. Some methods use the Shell command stty.
-The Shell command stty must be available accordingly. One method is using the
-system call ioctl, which is optional with respect to the functionality of the
-module. The restriction under Perl is explained further below.
+On operating systems that support ANSI escape sequences, individual methods
+will work out of the box. Some methods still use the Shell command C<stty>.
+The Shell command C<stty> must be available accordingly. Some methods are
+using the system call ioctl, which is somehow optional with respect to the
+functionality of the module. The restriction under Perl is explained further
+below.
 
-The above requirements are fulfilled in principle by all Unix or Unix-like systems. 
+The above requirements are fulfilled in principle by all Unix or Unix-like
+systems. 
 
 =head1 FUNCTIONALITY REQUIREMENT
 
@@ -890,11 +1006,11 @@ fallback solution based on the Shell command C<stty> is implemented.
 =head1 PORTABILITY
 
 The module should work on B<Linux> as well as B<Unix> or B<Unix-like>
-operating systems in general.
+operating systems in general until something else was shown.
 
 =head1 CONTROL SEQUENCES
 
-I<ANSI escape sequences> are widely known. Less well known are the so-called I<XTERM
+I<ANSI escape sequences> are widely known. Less well known are the so-called I<Xterm
 control sequences>.
 
 =head2 ANSI escape sequences
@@ -908,7 +1024,12 @@ Escape sequences used by the module:
   CSI ? 25 h   =>  DECTCEM  =>  Shows the cursor
   CSI ? 25 l   =>  DECTCEM  =>  Hides the cursor 
 
-=head2 XTERM control sequences
+=head2 Xterm control sequences
+
+The xterm program is a terminal emulator for the X Window System. The Xterm
+escape sequences take their name from the terminal emulator of the same name.
+This means that the Xterm escape sequences should primarily be able to run
+under xterm. However, they also work with other terminal emulators.
 
 Escape sequences used by the module:
 
@@ -926,12 +1047,42 @@ clear_screen and reset_screen can also be used with this aliases:
   reset           <=  reset_screen
   clear           <=  clear_screen
 
+=head1 TERMINALS TESTED
+
+As described above, terminal emulators or the system console are used to
+interact with the operating system.
+
+Terminals tested so far with the module:
+
+=over 4
+
+=item * xterm
+
+=item * ROXTerm
+
+=item * LXTerminal
+
+=back
+
+=head1 LIMITATIONS
+
+If the timeout is set too short, the response to the request cannot be
+evaluated. If information on the size of the window is requested in quick
+succession, the data from STDIN will be read in incorrectly. This is only
+possible by deleting STDIN. A method of deleting or resetting STDIN is not 
+known yet.
+
+=head1 OPEN ISSUES
+
+It is not yet clear how an installation of the module for Unix or Unix-like
+operating systems only can best be realised.  
+
+A routine is needed that can reliably delete STDIN. Previous attempts to delete
+STDIN did not lead to satisfactory results. 
+
 =head1 KNOWN BUGS
 
-It happens that in rare cases the CPAN test of the module gives several errors
-during compilation. The first error issued is actually an error. This error
-then obviously causes subsequent errors that are not actually errors. It is
-still unclear how the first real error can be permanently eliminated. 
+Not known yet
 
 =head1 ABSTRACT
 
@@ -941,7 +1092,7 @@ for using the module and its methods. The module contains, among others, two
 methods for clearing and resetting the terminal window. This is a standard
 task when scripts has to be executed in the terminal window. The related Shell
 commands are slow in comparison to the implemented methods in this module. This
-is achieved by using ANSI escape sequences. In addition XTERM control sequences
+is achieved by using ANSI escape sequences. In addition Xterm control sequences
 can be used to query screen and window size. The terminal or window size is in
 general available via the system call ioctl.
 
@@ -949,7 +1100,7 @@ general available via the system call ioctl.
 
 ANSI escape sequences
 
-XTERM control sequences
+Xterm control sequences
 
 stty(1) - Linux manual page 
 
